@@ -36,9 +36,9 @@ import org.junit.Test;
 /**
  * Unit tests {@link org.apache.commons.fileupload.DiskFileUpload}.
  *
- * @version $Id: ServletFileUploadTest.java 1455856 2013-03-13 09:59:33Z simonetripodi $
+ * @version $Id: ServletFileUploadTest.java 1564788 2014-02-05 14:36:41Z markt $
  */
-@SuppressWarnings("deprecation") // unit tests for deprecated class
+@SuppressWarnings({"deprecation", "javadoc"}) // unit tests for deprecated class
 public class ServletFileUploadTest extends FileUploadTestCase {
 
     @Test
